@@ -23,7 +23,7 @@ OC.L10N.register(
     "No unread articles available" : "Немає непрочитаних записів",
     "Open website" : "Відкрити веб-сайт",
     "Star article" : "Позначити статтю",
-    "Unstar article" : "Зняти позначку статті",
+    "Unstar article" : "Зняти зірочку зі статті",
     "Keep article unread" : "Залишити статтю непрочитаною",
     "Remove keep article unread" : "Позначити статтю як прочитану",
     "Share" : "Спільний доступ",
@@ -85,7 +85,7 @@ OC.L10N.register(
     "Collapse" : "Згорнути",
     "Deleted folder" : "Вилучений каталог",
     "Undo delete folder" : "Скасувати вилучення каталогу",
-    "Starred" : "Помічені зірочкою",
+    "Starred" : "Із зірочкою",
     "All articles" : "Всі статті",
     "Settings" : "Налаштування",
     "Disable mark read through scrolling" : "Вимкнути читання поміток при прокрутці",
